window.Gleam.initSearch([{"doc":"non_empty_list","title":"non_empty_list","content":"# non_empty_list\n\n[![Package Version](https://img.shields.io/hexpm/v/non_empty_list)](https://hex.pm/packages/non_empty_list)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/non_empty_list/)\n![CI](https://github.com/giacomocavalieri/non_empty_list/workflows/CI/badge.svg?branch=main)\n\n✨ Non-empty lists in Gleam\n\n&gt; ⚙️ This package supports both the Erlang and JavaScript target!\n\n## Installation\n\nTo add this package to your Gleam project:\n\n```sh\ngleam add non_empty_list\n```\n\n## Usage\n\nImport the `non_empty_list` module and write some code!\n\n```gleam\nimport non_empty_list\nimport gleam/int\nimport gleam/io\n\npub fn main() {\n  non_empty_list.new(1, [2, 3, 4])\n  |&gt; non_empty_list.reduce(with: fn(n, m) { n + m })\n  |&gt; int.to_string\n  |&gt; io.println\n}\n```\n\n## Contributing\n\nThis package exposes most of the same functions you&#39;d find in the `gleam/list`\nmodule but it may be missing some useful functions.\n\nIf you think there&#39;s a missing function that would fit here, or if you spot a\nbug don&#39;t be afraid to open PRs, issues or requests of any kind!\nAny contribution is welcome 💜\n","url":"index.html"},{"doc":"non_empty_list","title":"NonEmptyList","content":"pub type NonEmptyList(a) {\n  NonEmptyList(first: a, rest: List(a))\n}\n A list that is guaranteed to contain at least one item.\n\nNonEmptyList(first: a, rest: List(a))\n\n\nSynonyms:\nnon_empty_list.NonEmptyList\nnon_empty_list NonEmptyList","url":"non_empty_list.html#NonEmptyList"},{"doc":"non_empty_list","title":"append","content":"pub fn append(\n  first: NonEmptyList(a),\n  second: NonEmptyList(a),\n) -&gt; NonEmptyList(a)\n Joins a non-empty list onto the end of a non-empty list.\n\n This function runs in linear time, and it traverses and copies the first non-empty list.\n\n ## Examples\n\n \n &gt; new(1, [2, 3, 4])\n &gt; |&gt; append(new(5, [6, 7]))\n NonEmptyList(1, [2, 3, 4, 5, 6, 7])\n \n\n \n &gt; single(&quot;a&quot;)\n &gt; |&gt; append(new(&quot;b&quot;, [&quot;c&quot;])\n NonEmptyList(&quot;a&quot;, [&quot;b&quot;, &quot;c&quot;])\n `\n\nSynonyms:\nnon_empty_list.append\nnon_empty_list append","url":"non_empty_list.html#append"},{"doc":"non_empty_list","title":"append_list","content":"pub fn append_list(\n  first: NonEmptyList(a),\n  second: List(a),\n) -&gt; NonEmptyList(a)\n Joins a list onto the end of a non-empty list.\n\n This function runs in linear time, and it traverses and copies the first non-empty list.\n\n ## Examples\n\n \n &gt; new(1, [2, 3, 4])\n &gt; |&gt; append_list([5, 6, 7])\n NonEmptyList(1, [2, 3, 4, 5, 6, 7])\n \n\n \n &gt; new(&quot;a&quot;, [&quot;b&quot;, &quot;c&quot;])\n &gt; |&gt; append_list([])\n NonEmptyList(&quot;a&quot;, [&quot;b&quot;, &quot;c&quot;])\n \n\nSynonyms:\nnon_empty_list.append_list\nnon_empty_list append_list","url":"non_empty_list.html#append_list"},{"doc":"non_empty_list","title":"drop","content":"pub fn drop(from list: NonEmptyList(a), up_to n: Int) -&gt; List(a)\n Returns a list that is the given non-empty list with up to the given\n number of elements removed from the front of the list.\n\n ## Examples\n\n \n &gt; new(&quot;a&quot;, [&quot;b&quot;, &quot;c&quot;])\n &gt; |&gt; drop(up_to: 2)\n [&quot;c&quot;]\n \n\n \n &gt; new(&quot;a&quot;, [&quot;b&quot;, &quot;c&quot;])\n &gt; |&gt; drop(up_to: 3)\n []\n \n\nSynonyms:\nnon_empty_list.drop\nnon_empty_list drop","url":"non_empty_list.html#drop"},{"doc":"non_empty_list","title":"first","content":"pub fn first(list: NonEmptyList(a)) -&gt; a\n Gets the first element from the start of the non-empty list.\n\n ## Examples\n\n \n &gt; new(1, [2, 3, 4])\n &gt; |&gt; first\n 1\n \n\nSynonyms:\nnon_empty_list.first\nnon_empty_list first","url":"non_empty_list.html#first"},{"doc":"non_empty_list","title":"flat_map","content":"pub fn flat_map(\n  over list: NonEmptyList(a),\n  with fun: fn(a) -&gt; NonEmptyList(b),\n) -&gt; NonEmptyList(b)\n Maps the non-empty list with the given function and then flattens it.\n\n ## Examples\n\n \n &gt; new(1, [3, 5])\n &gt; |&gt; flat_map(fn(x) { new(x, [x + 1]) })\n NonEmptyList(1, [2, 3, 4, 5, 6])\n \n\nSynonyms:\nnon_empty_list.flat_map\nnon_empty_list flat_map","url":"non_empty_list.html#flat_map"},{"doc":"non_empty_list","title":"flatten","content":"pub fn flatten(\n  lists: NonEmptyList(NonEmptyList(a)),\n) -&gt; NonEmptyList(a)\n Flattens a non-empty list of non-empty lists into a single non-empty list.\n\n This function traverses all elements twice.\n\n ### Examples\n\n \n &gt; new(new(1, [2, 3]), [new(3, [4, 5])])\n &gt; |&gt; flatten\n NonEmptyList(1, [2, 3, 4, 5])\n \n\nSynonyms:\nnon_empty_list.flatten\nnon_empty_list flatten","url":"non_empty_list.html#flatten"},{"doc":"non_empty_list","title":"from_list","content":"pub fn from_list(list: List(a)) -&gt; Result(NonEmptyList(a), Nil)\n Attempts to turn a list into a non-empty list, fails if the starting\n list is empty.\n\n ## Examples\n\n \n &gt; from_list([1, 2, 3, 4])\n Ok(NonEmptyList(1, [2, 3, 4]))\n \n\n \n &gt; from_list([&quot;a&quot;])\n Ok(NonEmptyList(&quot;a&quot;, []))\n \n\n \n &gt; from_list([])\n Error(Nil)\n \n\nSynonyms:\nnon_empty_list.from_list\nnon_empty_list from_list","url":"non_empty_list.html#from_list"},{"doc":"non_empty_list","title":"index_map","content":"pub fn index_map(\n  list: NonEmptyList(a),\n  with fun: fn(Int, a) -&gt; b,\n) -&gt; NonEmptyList(b)\n Returns a new list containing only the elements of the first list after the\n function has been applied to each one and their index.\n\n The index starts at 0, so the first element is 0, the second is 1, and so on.\n\n ## Examples\n\n \n &gt; new(&quot;a&quot;, [&quot;b&quot;, &quot;c&quot;])\n &gt; |&gt; index_map(fn(index, letter) { #(index, letter) })\n NonEmpty(#(0, &quot;a&quot;), [#(1, &quot;b&quot;), #(2, &quot;c&quot;)])\n \n\nSynonyms:\nnon_empty_list.index_map\nnon_empty_list index_map","url":"non_empty_list.html#index_map"},{"doc":"non_empty_list","title":"intersperse","content":"pub fn intersperse(\n  list: NonEmptyList(a),\n  with elem: a,\n) -&gt; NonEmptyList(a)\n Inserts a given value between each existing element in a given list.\n\n This function runs in linear time and copies the list.\n\n ## Examples\n\n \n &gt; new(1, [2, 3, 4])\n &gt; |&gt; intersperse(with: 0)\n NonEmptyList(1, [0, 2, 0, 3, 0, 4])\n \n\n \n &gt; single(&quot;a&quot;)\n &gt; |&gt; intersperse(with: &quot;z&quot;)\n NonEmptyList(&quot;a&quot;, [&quot;z&quot;])\n \n\nSynonyms:\nnon_empty_list.intersperse\nnon_empty_list intersperse","url":"non_empty_list.html#intersperse"},{"doc":"non_empty_list","title":"last","content":"pub fn last(list: NonEmptyList(a)) -&gt; a\n Returns the last element in the given list.\n\n This function runs in linear time.\n For a collection oriented around performant access at either end,\n see `gleam/queue.Queue`.\n\n ## Examples\n\n \n &gt; single(1)\n &gt; |&gt; last\n 1\n \n\n \n &gt; new(1, [2, 3, 4])\n &gt; |&gt; last\n 4\n \n\nSynonyms:\nnon_empty_list.last\nnon_empty_list last","url":"non_empty_list.html#last"},{"doc":"non_empty_list","title":"map","content":"pub fn map(\n  over list: NonEmptyList(a),\n  with fun: fn(a) -&gt; b,\n) -&gt; NonEmptyList(b)\n Returns a new non-empty list containing only the elements of the first\n non-empty list after the function has been applied to each one.\n\n ## Examples\n\n \n &gt; new(1, [2, 3])\n &gt; |&gt; map(fn(x) { x + 1 })\n NonEmpty(2, [3, 4])\n \n\nSynonyms:\nnon_empty_list.map\nnon_empty_list map","url":"non_empty_list.html#map"},{"doc":"non_empty_list","title":"map2","content":"pub fn map2(\n  list1: NonEmptyList(a),\n  list2: NonEmptyList(b),\n  with fun: fn(a, b) -&gt; c,\n) -&gt; NonEmptyList(c)\n Combines two non-empty lists into a single non-empty list using the given\n function.\n\n If a list is longer than the other the extra elements are dropped.\n\n ## Examples\n\n \n &gt; map2(new(1, [2, 3]), new(4, [5, 6]), fn(x, y) { x + y }) |&gt; to_list\n [5, 7, 9]\n \n\n \n &gt; map2(new(1, [2]), new(&quot;a&quot;, [&quot;b&quot;, &quot;c&quot;]), fn(i, x) { #(i, x) }) |&gt; to_list\n [#(1, &quot;a&quot;), #(2, &quot;b&quot;)]\n \n\nSynonyms:\nnon_empty_list.map2\nnon_empty_list map2","url":"non_empty_list.html#map2"},{"doc":"non_empty_list","title":"map_fold","content":"pub fn map_fold(\n  over list: NonEmptyList(a),\n  from acc: b,\n  with fun: fn(b, a) -&gt; #(b, c),\n) -&gt; #(b, NonEmptyList(c))\n Similar to `map` but also lets you pass around an accumulated value.\n\n ## Examples\n\n \n &gt; new(1, [2, 3])\n &gt; |&gt; map_fold(from: 100, with: fn(memo, n) { #(memo + i, i * 2) })\n #(106, NonEmpty(2, [4, 6]))\n \n\nSynonyms:\nnon_empty_list.map_fold\nnon_empty_list map_fold","url":"non_empty_list.html#map_fold"},{"doc":"non_empty_list","title":"new","content":"pub fn new(first: a, rest: List(a)) -&gt; NonEmptyList(a)\n Creates a new non-empty list given its first element and a list\n for the rest of the elements.\n\n ## Examples\n\n \n &gt; new(1, [2, 3, 4])\n NonEmptyList(1, [2, 3, 4])\n \n \n &gt; new(&quot;a&quot;, [])\n NonEmptyList(&quot;a&quot;, [])\n \n\nSynonyms:\nnon_empty_list.new\nnon_empty_list new","url":"non_empty_list.html#new"},{"doc":"non_empty_list","title":"prepend","content":"pub fn prepend(\n  to list: NonEmptyList(a),\n  this item: a,\n) -&gt; NonEmptyList(a)\n Prefixes an item to a non-empty list.\n\n ## Examples\n\n \n &gt; new(2, [3, 4])\n &gt; |&gt; prepend(1)\n NonEmptyList(1, [2, 3, 4])\n \n\nSynonyms:\nnon_empty_list.prepend\nnon_empty_list prepend","url":"non_empty_list.html#prepend"},{"doc":"non_empty_list","title":"reduce","content":"pub fn reduce(\n  over list: NonEmptyList(a),\n  with fun: fn(a, a) -&gt; a,\n) -&gt; a\n This function acts similar to fold, but does not take an initial state.\n Instead, it starts from the first element in the non-empty list and combines it with each\n subsequent element in turn using the given function.\n The function is called as `fun(accumulator, current_element)`.\n\n ## Examples\n\n \n &gt; new(1, [2, 3, 4])\n &gt; |&gt; reduce(fn(acc, x) { acc + x })\n 10\n \n\nSynonyms:\nnon_empty_list.reduce\nnon_empty_list reduce","url":"non_empty_list.html#reduce"},{"doc":"non_empty_list","title":"rest","content":"pub fn rest(list: NonEmptyList(a)) -&gt; List(a)\n Returns the list minus the first element. Since the remaining list could\n be empty this functions returns a normal list.\n\n ## Examples\n\n \n &gt; new(1, [2, 3, 4])\n &gt; |&gt; rest\n [2, 3, 4]\n \n\n \n &gt; single(1)\n &gt; |&gt; rest\n []\n \n\nSynonyms:\nnon_empty_list.rest\nnon_empty_list rest","url":"non_empty_list.html#rest"},{"doc":"non_empty_list","title":"reverse","content":"pub fn reverse(list: NonEmptyList(a)) -&gt; NonEmptyList(a)\n Creates a new non-empty list from a given non-empty list containing the same elements\n but in the opposite order.\n\n This function has to traverse the non-empty list to create the new reversed\n non-empty list, so it runs in linear time.\n\n ## Examples\n\n \n &gt; new(1, [2, 3, 4])\n &gt; |&gt; reverse\n NonEmptyList(4, [3, 2, 1])\n \n\nSynonyms:\nnon_empty_list.reverse\nnon_empty_list reverse","url":"non_empty_list.html#reverse"},{"doc":"non_empty_list","title":"scan","content":"pub fn scan(\n  over list: NonEmptyList(a),\n  from initial: b,\n  with fun: fn(b, a) -&gt; b,\n) -&gt; NonEmptyList(b)\n Similar to fold, but yields the state of the accumulator at each stage.\n\n ## Examples\n\n \n &gt; new(1, [2, 3, 4])\n &gt; |&gt; scan(from: 100, with: fn(acc, i) { acc + i })\n NonEmptyList(101 [103, 106, 110])\n \n\nSynonyms:\nnon_empty_list.scan\nnon_empty_list scan","url":"non_empty_list.html#scan"},{"doc":"non_empty_list","title":"shuffle","content":"pub fn shuffle(list: NonEmptyList(a)) -&gt; NonEmptyList(a)\n Takes a non-empty list, randomly sorts all items and returns the shuffled\n non-empty list.\n\n This function uses Erlang&#39;s `:rand` module or Javascript&#39;s\n `Math.random()` to calcuate the index shuffling.\n\n ## Examples\n\n \n &gt; new(&quot;a&quot;, [&quot;b&quot;, &quot;c&quot;, &quot;d&quot;])\n &gt; |&gt; shuffle\n NonEmptyList(&quot;c&quot;, [&quot;a&quot;, &quot;d&quot;, &quot;b&quot;])\n \n\nSynonyms:\nnon_empty_list.shuffle\nnon_empty_list shuffle","url":"non_empty_list.html#shuffle"},{"doc":"non_empty_list","title":"single","content":"pub fn single(first: a) -&gt; NonEmptyList(a)\n Creates a non-empty list with a single element.\n\n ## Examples\n\n \n &gt; single(1)\n NonEmptyList(1, [])\n \n\nSynonyms:\nnon_empty_list.single\nnon_empty_list single","url":"non_empty_list.html#single"},{"doc":"non_empty_list","title":"sort","content":"pub fn sort(\n  list: NonEmptyList(a),\n  by compare: fn(a, a) -&gt; Order,\n) -&gt; NonEmptyList(a)\n Sorts a given non-empty list from smallest to largest based upon the\n ordering specified by a given function.\n\n ## Examples\n\n \n &gt; import gleam/int\n &gt; new(4, [1, 3, 4, 2, 6, 5])\n &gt; sort(by: int.compare)\n NonEmptyList(1, [2, 3, 4, 4, 5, 6])\n \n\nSynonyms:\nnon_empty_list.sort\nnon_empty_list sort","url":"non_empty_list.html#sort"},{"doc":"non_empty_list","title":"strict_zip","content":"pub fn strict_zip(\n  list: NonEmptyList(a),\n  with other: NonEmptyList(b),\n) -&gt; Result(NonEmptyList(#(a, b)), Nil)\n Takes two non-empty lists and returns a single non-empty list of 2-element tuples.\n\n If one of the non-empty lists is longer than the other, an `Error` is returned.\n\n ## Examples\n\n \n &gt; strict_zip(single(1), new(&quot;a&quot;, [&quot;b&quot;, &quot;c&quot;]))\n Error(Nil)\n \n\n \n &gt; strict_zip(new(1, [2, 3]), single(&quot;a&quot;))\n Error(Nil)\n \n\n \n &gt; strict_zip(new(1, [2, 3]), new(&quot;a&quot;, [&quot;b&quot;, &quot;c&quot;]))\n Ok(NonEmptyList(#(1, &quot;a&quot;), [#(2, &quot;b&quot;), #(3, &quot;c&quot;)]))\n \n\nSynonyms:\nnon_empty_list.strict_zip\nnon_empty_list strict_zip","url":"non_empty_list.html#strict_zip"},{"doc":"non_empty_list","title":"take","content":"pub fn take(from list: NonEmptyList(a), up_to n: Int) -&gt; List(a)\n Returns a list containing the first given number of elements from the given\n non-empty list.\n\n If the element has less than the number of elements then the full list is\n returned.\n\n This function runs in linear time but does not copy the list.\n\n ## Examples\n\n \n &gt; new(1, [2, 3, 4])\n &gt; take(2)\n [1, 2]\n \n\n \n &gt; new(1, [2, 3, 4])\n &gt; take(9)\n [1, 2, 3, 4]\n \n\nSynonyms:\nnon_empty_list.take\nnon_empty_list take","url":"non_empty_list.html#take"},{"doc":"non_empty_list","title":"to_list","content":"pub fn to_list(non_empty: NonEmptyList(a)) -&gt; List(a)\n Turns a non-empty list back into a normal list with the same\n elements.\n\n ## Examples\n\n \n &gt; new(1, [2, 3, 4])\n &gt; |&gt; to_list\n [1, 2, 3, 4]\n \n\n \n &gt; single(&quot;a&quot;)\n &gt; |&gt; to_list\n [&quot;a&quot;]\n \n\nSynonyms:\nnon_empty_list.to_list\nnon_empty_list to_list","url":"non_empty_list.html#to_list"},{"doc":"non_empty_list","title":"unique","content":"pub fn unique(list: NonEmptyList(a)) -&gt; NonEmptyList(a)\n Removes any duplicate elements from a given list.\n\n This function returns in loglinear time.\n\n ## Examples\n\n \n &gt; new(1, [1, 2, 3, 1, 4, 4, 3])\n &gt; |&gt; unique\n NonEmptyList(1, [2, 3, 4])\n \n\nSynonyms:\nnon_empty_list.unique\nnon_empty_list unique","url":"non_empty_list.html#unique"},{"doc":"non_empty_list","title":"unzip","content":"pub fn unzip(\n  list: NonEmptyList(#(a, b)),\n) -&gt; #(NonEmptyList(a), NonEmptyList(b))\n Takes a single non-empty list of 2-element tuples and returns two\n non-empty lists.\n\n ## Examples\n\n \n &gt; new(#(1, &quot;a&quot;), [#(2, &quot;b&quot;), #(3, &quot;c&quot;)])\n &gt; |&gt; unzip\n #(NonEmptyList(1, [2, 3]), NonEmptyList(&quot;a&quot;, [&quot;b&quot;, &quot;c&quot;]))\n \n\nSynonyms:\nnon_empty_list.unzip\nnon_empty_list unzip","url":"non_empty_list.html#unzip"},{"doc":"non_empty_list","title":"zip","content":"pub fn zip(\n  list: NonEmptyList(a),\n  with other: NonEmptyList(b),\n) -&gt; NonEmptyList(#(a, b))\n Takes two non-empty lists and returns a single non-empty list of 2-element tuples.\n\n If one of the non-empty lists is longer than the other, the remaining elements from\n the longer non-empty list are not used.\n\n ## Examples\n\n \n &gt; zip(new(1, [2, 3]), single(&quot;a&quot;))\n NonEmptyList(#(1, &quot;a&quot;), [])\n \n\n \n &gt; zip(single(1), new(&quot;a&quot;, [&quot;b&quot;, &quot;c&quot;]))\n NonEmptyList(#(1, &quot;a&quot;), [])\n \n\n \n &gt; zip(new(1, [2, 3]), new(&quot;a&quot;, [&quot;b&quot;, &quot;c&quot;]))\n NonEmptyList(#(1, &quot;a&quot;), [#(2, &quot;b&quot;), #(3, &quot;c&quot;)])\n \n\nSynonyms:\nnon_empty_list.zip\nnon_empty_list zip","url":"non_empty_list.html#zip"},{"doc":"non_empty_list","title":"non_empty_list","content":"","url":"non_empty_list.html"}]);